use std::ops::Add;

pub type PosInt = i16;

#[derive(Debug, Default, Clone, Copy, PartialEq)]
pub struct Pos {
	pub x: PosInt,
	pub y: PosInt,
}

impl Pos {
	pub fn min(self, other: Self) -> Self {
		Self {
			x: self.x.min(other.x),
			y: self.y.min(other.y),
		}
	}

	pub fn max(self, other: Self) -> Self {
		Self {
			x: self.x.max(other.x),
			y: self.y.max(other.y),
		}
	}
}

impl From<(usize, usize)> for Pos {
	fn from(value: (usize, usize)) -> Self {
		Self {
			x: value.0 as PosInt,
			y: value.1 as PosInt,
		}
	}
}

impl From<(i32, i32)> for Pos {
	fn from(value: (i32, i32)) -> Self {
		Self {
			x: value.0 as PosInt,
			y: value.1 as PosInt,
		}
	}
}

impl Add for Pos {
	type Output = Self;
	fn add(self, rhs: Self) -> Self::Output {
		Self {
			x: self.x + rhs.x,
			y: self.y + rhs.y,
		}
	}
}
